@@ -20,23 +20,22 @@ describe 'murano::policy' do
         :key   => 'context_is_admin',
         :value => 'foo:bar'
       })
-      is_expected.to contain_murano_config('oslo_policy/policy_file').with_value('/etc/murano/policy.json')
+      is_expected.to contain_oslo__policy('murano_config').with(
+        :policy_file => '/etc/murano/policy.json',
+      )
     end
   end
 
-  context 'on Debian platforms' do
-    let :facts do
-      { :osfamily => 'Debian' }
-    end
+  on_supported_os({
+    :supported_os   => OSDefaults.get_supported_os
+  }).each do |os,facts|
+    context "on #{os}" do
+      let (:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
-    it_configures 'murano policies'
+      it_configures 'murano policies'
+    end
   end
 
-  context 'on RedHat platforms' do
-    let :facts do
-      { :osfamily => 'RedHat' }
-    end
-
-    it_configures 'murano policies'
-  end
 end
